@@ -13,6 +13,7 @@ Register = namedtuple('Register', 'name value')
 class CrashReport:
     def __init__(self, buf: str, filename: str = None):
         self.filename = filename
+        self.buf = buf
         self._metadata, self._data = buf.split('\n', 1)
         self._metadata = json.loads(self._metadata)
         self._parse()
@@ -39,15 +40,15 @@ class CrashReport:
 
     @cached_property
     def incident_id(self):
-        return self._metadata['incident_id']
+        return self._metadata.get('incident_id')
 
     @cached_property
     def timestamp(self):
-        return self._metadata['timestamp']
+        return self._metadata.get('timestamp')
 
     @cached_property
     def name(self) -> str:
-        return self._metadata['name']
+        return self._metadata.get('name')
 
     @cached_property
     def faulting_thread(self) -> int:
